@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_divmod.c                                                          *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -65,7 +65,7 @@ GMPy_Integer_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
 
             if (error) {
                 /* Use quo->z as a temporary variable. */
-                mpz_set_PyIntOrLong(quo->z, y);
+                mpz_set_PyLong(quo->z, y);
                 GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
                 mpz_fdiv_qr(quo->z, rem->z, MPZ(x), quo->z);
                 GMPY_MAYBE_END_ALLOW_THREADS(context);
@@ -94,7 +94,7 @@ GMPy_Integer_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                 goto error;
             }
             else {
-                mpz_set_PyIntOrLong(quo->z, x);
+                mpz_set_PyLong(quo->z, x);
                 GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
                 mpz_fdiv_qr(quo->z, rem->z, quo->z, MPZ(y));
                 GMPY_MAYBE_END_ALLOW_THREADS(context);
@@ -201,7 +201,7 @@ GMPy_Rational_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
 }
 
 static PyObject *
-GMPy_Real_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype, 
+GMPy_Real_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                          CTXT_Object *context)
 {
     MPFR_Object *tempx = NULL, *tempy = NULL, *quo = NULL, *rem = NULL, *temp;
@@ -322,7 +322,7 @@ GMPy_Real_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
 }
 
 static PyObject *
-GMPy_Complex_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype, 
+GMPy_Complex_DivModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                             CTXT_Object *context)
 {
     TYPE_ERROR("can't take floor or mod of complex number.");
@@ -334,7 +334,7 @@ GMPy_Number_DivMod_Slot(PyObject *x, PyObject *y)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_DivModWithType(x, xtype, y, ytype, NULL);
 
@@ -343,7 +343,7 @@ GMPy_Number_DivMod_Slot(PyObject *x, PyObject *y)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_DivModWithType(x, xtype, y, ytype, NULL);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_DivModWithType(x, xtype, y, ytype, NULL);
 
@@ -355,7 +355,7 @@ GMPy_Number_DivMod(PyObject *x, PyObject *y, CTXT_Object *context)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_DivModWithType(x, xtype, y, ytype, NULL);
 
@@ -364,7 +364,7 @@ GMPy_Number_DivMod(PyObject *x, PyObject *y, CTXT_Object *context)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_DivModWithType(x, xtype, y, ytype, NULL);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_DivModWithType(x, xtype, y, ytype, NULL);
 
@@ -373,30 +373,20 @@ GMPy_Number_DivMod(PyObject *x, PyObject *y, CTXT_Object *context)
 }
 
 PyDoc_STRVAR(GMPy_doc_context_divmod,
-"context.div_mod(x, y) -> (quotient, remainder)\n\n"
-"Return div_mod(x, y); uses alternate spelling to avoid naming conflicts.\n"
+"context.divmod(x, y, /) -> tuple[mpz|mpfr, mpz|mpq|mpfr]\n\n"
+"Return divmod(x, y).\n\n"
 "Note: overflow, underflow, and inexact exceptions are not supported for\n"
-"mpfr arguments to context.div_mod().");
+"`mpfr` arguments.");
 
 static PyObject *
 GMPy_Context_DivMod(PyObject *self, PyObject *args)
 {
-    CTXT_Object *context = NULL;
-
     if (PyTuple_GET_SIZE(args) != 2) {
         TYPE_ERROR("div_mod() requires 2 arguments");
         return NULL;
     }
 
-    if (self && CTXT_Check(self)) {
-        context = (CTXT_Object*)self;
-    }
-    else {
-        CHECK_CONTEXT(context);
-    }
-
     return GMPy_Number_DivMod(PyTuple_GET_ITEM(args, 0),
                               PyTuple_GET_ITEM(args, 1),
-                              context);
+                              (CTXT_Object*)self);
 }
-
