@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_fused.c                                                           *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -187,11 +187,11 @@ GMPy_ComplexWithType_FMA(PyObject *x, int xtype, PyObject *y, int ytype, PyObjec
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fma,
-"context.fma(x, y, z) -> number\n\n"
+"context.fma(x, y, z, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return correctly rounded result of (x * y) + z.");
 
 PyDoc_STRVAR(GMPy_doc_function_fma,
-"fma(x, y, z) -> number\n\n"
+"fma(x, y, z, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return correctly rounded result of (x * y) + z.");
 
 GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMA, fma);
@@ -362,11 +362,11 @@ GMPy_ComplexWithType_FMS(PyObject *x, int xtype, PyObject *y, int ytype, PyObjec
     return result;
 }
 PyDoc_STRVAR(GMPy_doc_context_fms,
-"context.fms(x, y, z) -> number\n\n"
+"context.fms(x, y, z, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return correctly rounded result of (x * y) - z.");
 
 PyDoc_STRVAR(GMPy_doc_function_fms,
-"fms(x, y, z) -> number\n\n"
+"fms(x, y, z, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return correctly rounded result of (x * y) - z.");
 
 GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMS, fms);
@@ -521,11 +521,11 @@ GMPy_RealWithType_FMMA(PyObject *x, int xtype, PyObject *y, int ytype, PyObject
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fmma,
-"context.fmma(x, y, z, t) -> number\n\n"
+"context.fmma(x, y, z, t, /) -> mpfr\n\n"
 "Return correctly rounded result of (x * y) + (z * t).");
 
 PyDoc_STRVAR(GMPy_doc_function_fmma,
-"fmma(x, y, z, t) -> number\n\n"
+"fmma(x, y, z, t, /) -> mpfr\n\n"
 "Return correctly rounded result of (x * y) + (z + t).");
 
 GMPY_MPFR_QUADOP_TEMPLATEWT(FMMA, fmma);
@@ -676,15 +676,13 @@ GMPy_RealWithType_FMMS(PyObject *x, int xtype, PyObject *y, int ytype, PyObject
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fmms,
-"context.fmms(x, y, z, t) -> number\n\n"
+"context.fmms(x, y, z, t, /) -> mpfr\n\n"
 "Return correctly rounded result of (x * y) - (z * t).");
 
 PyDoc_STRVAR(GMPy_doc_function_fmms,
-"fmms(x, y, z, t) -> number\n\n"
+"fmms(x, y, z, t, /) -> mpfr\n\n"
 "Return correctly rounded result of (x * y) - (z + t).");
 
 GMPY_MPFR_QUADOP_TEMPLATEWT(FMMS, fmms);
 
 #endif
-
-
