@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_misc.c                                                            *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -37,9 +37,6 @@ static PyObject * GMPy_get_mp_version(PyObject *self, PyObject *args);
 static PyObject * GMPy_get_mpfr_version(PyObject *self, PyObject *args);
 static PyObject * GMPy_get_mpc_version(PyObject *self, PyObject *args);
 static PyObject * GMPy_get_mp_limbsize(PyObject *self, PyObject *args);
-static PyObject * GMPy_get_cache(PyObject *self, PyObject *args);
-static PyObject * GMPy_set_cache(PyObject *self, PyObject *args);
-static PyObject * GMPy_printf(PyObject *self, PyObject *args);
 
 #ifdef __cplusplus
 }
