@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_mod.c                                                             *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -28,7 +28,7 @@
  */
 
 static PyObject *
-GMPy_Integer_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype, 
+GMPy_Integer_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                          CTXT_Object *context)
 {
     MPZ_Object *result;
@@ -72,7 +72,7 @@ GMPy_Integer_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                 }
             }
             else {
-                mpz_set_PyIntOrLong(result->z, y);
+                mpz_set_PyLong(result->z, y);
                 GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
                 mpz_fdiv_r(result->z, MPZ(x), result->z);
                 GMPY_MAYBE_END_ALLOW_THREADS(context);
@@ -89,8 +89,8 @@ GMPy_Integer_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
             return NULL;
         }
 
-        if (PyIntOrLong_Check(x)) {
-            mpz_set_PyIntOrLong(result->z, x);
+        if (PyLong_Check(x)) {
+            mpz_set_PyLong(result->z, x);
             mpz_fdiv_r(result->z, result->z, MPZ(y));
             return (PyObject*)result;
         }
@@ -124,9 +124,11 @@ GMPy_Integer_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("mod() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 static PyObject *
@@ -146,7 +148,7 @@ GMPy_Rational_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return NULL;
         /* LCOV_EXCL_STOP */
     }
-    
+
     if (IS_TYPE_RATIONAL(xtype) && IS_TYPE_RATIONAL(ytype)) {
         if (!(tempx = GMPy_MPQ_From_RationalWithType(x, xtype, context)) ||
             !(tempy = GMPy_MPQ_From_RationalWithType(y, ytype, context))) {
@@ -182,9 +184,11 @@ GMPy_Rational_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("mod() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 static PyObject *
@@ -260,9 +264,11 @@ GMPy_Real_ModWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("mod() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 
   error:
     Py_XDECREF((PyObject*)tempx);
@@ -284,7 +290,7 @@ GMPy_Number_Mod_Slot(PyObject *x, PyObject *y)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_ModWithType(x, xtype, y, ytype, NULL);
 
@@ -293,7 +299,7 @@ GMPy_Number_Mod_Slot(PyObject *x, PyObject *y)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_ModWithType(x, xtype, y, ytype, NULL);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_ModWithType(x, xtype, y, ytype, NULL);
 
@@ -301,7 +307,7 @@ GMPy_Number_Mod_Slot(PyObject *x, PyObject *y)
 }
 
 PyDoc_STRVAR(GMPy_doc_mod,
-"mod(x, y) -> number\n\n"
+"mod(x, y, /) -> mpz|mpq|mpfr\n\n"
 "Return mod(x, y).\n"
 "Note: overflow, underflow, and inexact exceptions are not supported for\n"
 "mpfr arguments to mod().");
@@ -311,7 +317,7 @@ GMPy_Number_Mod(PyObject *x, PyObject *y, CTXT_Object *context)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_ModWithType(x, xtype, y, ytype, context);
 
@@ -320,7 +326,7 @@ GMPy_Number_Mod(PyObject *x, PyObject *y, CTXT_Object *context)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_ModWithType(x, xtype, y, ytype, context);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_ModWithType(x, xtype, y, ytype, context);
 
@@ -329,10 +335,10 @@ GMPy_Number_Mod(PyObject *x, PyObject *y, CTXT_Object *context)
 }
 
 PyDoc_STRVAR(GMPy_doc_context_mod,
-"context.mod(x, y) -> number\n\n"
+"context.mod(x, y, /) -> mpz|mpq|mpfr\n\n"
 "Return mod(x, y).\n"
 "Note: overflow, underflow, and inexact exceptions are not supported for\n"
-"mpfr arguments to context.mod().");
+"`mpfr` arguments.");
 
 static PyObject *
 GMPy_Context_Mod(PyObject *self, PyObject *args)
@@ -355,4 +361,3 @@ GMPy_Context_Mod(PyObject *self, PyObject *args)
                            PyTuple_GET_ITEM(args, 1),
                            context);
 }
-
