@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_mpmath.c                                                          *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -33,29 +33,35 @@ mpmath_build_mpf(long sign, MPZ_Object *man, PyObject *exp, mp_bitcnt_t bc)
     PyObject *tup, *tsign, *tbc;
 
     if (!(tup = PyTuple_New(4))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_DECREF(exp);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
 
-    if (!(tsign = PyIntOrLong_FromLong(sign))) {
+    if (!(tsign = PyLong_FromLong(sign))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_DECREF(exp);
         Py_DECREF(tup);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
 
-    if (!(tbc = PyIntOrLong_FromMpBitCnt(bc))) {
+    if (!(tbc = GMPy_PyLong_FromMpBitCnt(bc))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_DECREF(exp);
         Py_DECREF(tup);
         Py_DECREF(tsign);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
 
     PyTuple_SET_ITEM(tup, 0, tsign);
     PyTuple_SET_ITEM(tup, 1, (PyObject*)man);
-    PyTuple_SET_ITEM(tup, 2, (exp)?exp:PyIntOrLong_FromLong(0));
+    PyTuple_SET_ITEM(tup, 2, (exp)?exp:PyLong_FromLong(0));
     PyTuple_SET_ITEM(tup, 3, tbc);
     return tup;
 }
@@ -67,8 +73,8 @@ mpmath_get_sign(PyObject *x)
      * value of 1 implies negative.
      */
 
-    if (PyIntOrLong_Check(x)) {
-        return PyIntOrLong_AsLong(x);
+    if (PyLong_Check(x)) {
+        return PyLong_AsLong(x);
     }
 
     if (MPZ_Check(x)) {
@@ -79,34 +85,35 @@ mpmath_get_sign(PyObject *x)
             return 0;
         }
     }
-       
+
     TYPE_ERROR("could not convert object to integer");
-    return (long)-1; 
+    return (long)-1;
 }
 
 PyDoc_STRVAR(doc_mpmath_normalizeg,
 "_mpmath_normalize(...): helper function for mpmath.");
 
 static PyObject *
-Pympz_mpmath_normalize(PyObject *self, PyObject *args)
+Pympz_mpmath_normalize_fast(PyObject *self, PyObject *const *args, Py_ssize_t nargs)
 {
-    long sign = 0, zbits, bc = 0, prec = 0, carry = 0;
-    mp_bitcnt_t shift = 0;
+    long sign = 0;
+    long carry = 0;
+    mp_bitcnt_t zbits, shift = 0, bc = 0, prec = 0;
     PyObject *exp = NULL, *newexp = NULL, *newexp2 = NULL, *tmp = NULL, *rndstr = NULL;
     MPZ_Object *man = NULL, *upper = NULL, *lower = NULL;
-    Py2or3String_Type rnd = 0;
+    Py_UCS4 rnd = 0;
 
-    if (PyTuple_GET_SIZE(args) == 6) {
+    if (nargs == 6) {
         /* Need better error-checking here. Under Python 3.0, overflow into
            C-long is possible. */
-        sign = mpmath_get_sign(PyTuple_GET_ITEM(args, 0));
-        man = (MPZ_Object*)PyTuple_GET_ITEM(args, 1);
-        exp = PyTuple_GET_ITEM(args, 2);
-        bc = GMPy_Integer_AsLong(PyTuple_GET_ITEM(args, 3));
-        prec = GMPy_Integer_AsLong(PyTuple_GET_ITEM(args, 4));
-        rndstr = PyTuple_GET_ITEM(args, 5);
+        sign = mpmath_get_sign(args[0]);
+        man = (MPZ_Object*)args[1];
+        exp = args[2];
+        bc = GMPy_PyLong_AsMpBitCnt(args[3]);
+        prec = GMPy_PyLong_AsMpBitCnt(args[4]);
+        rndstr = args[5];
 
-        if ((sign == -1) || (bc == -1) || (prec == -1)) {
+        if ((sign == -1) || (bc == (mp_bitcnt_t)(-1)) || (prec == (mp_bitcnt_t)(-1))) {
             TYPE_ERROR("arguments long, MPZ_Object*, PyObject*, long, long, char needed");
             return NULL;
         }
@@ -117,16 +124,16 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
     }
 
     if (!MPZ_Check(man)) {
-		/* Try to convert to an mpz... */
-		if (!(man = GMPy_MPZ_From_Integer((PyObject*)man, NULL))) {
-			TYPE_ERROR("argument is not an mpz");
-			return NULL;
-		}
+        /* Try to convert to an mpz... */
+        if (!(man = GMPy_MPZ_From_Integer((PyObject*)man, NULL))) {
+            TYPE_ERROR("argument is not an mpz");
+            return NULL;
+        }
     }
 
     /* If rndstr really is a string, extract the first character. */
-    if (Py2or3String_Check(rndstr)) {
-        rnd = Py2or3String_1Char(rndstr);
+    if (PyUnicode_Check(rndstr)) {
+        rnd = PyString_1Char(rndstr);
     }
     else {
         VALUE_ERROR("invalid rounding mode specified");
@@ -147,15 +154,17 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
     }
 
     if (!(upper = GMPy_MPZ_New(NULL)) || !(lower = GMPy_MPZ_New(NULL))) {
+        /* LCOV_EXCL_START */
         Py_XDECREF((PyObject*)upper);
         Py_XDECREF((PyObject*)lower);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
 
     if (bc > prec) {
         shift = bc - prec;
         switch (rnd) {
-            case (Py2or3String_Type)'f':
+            case (Py_UCS4)'f':
                 if(sign) {
                     mpz_cdiv_q_2exp(upper->z, man->z, shift);
                 }
@@ -163,7 +172,7 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
                     mpz_fdiv_q_2exp(upper->z, man->z, shift);
                 }
                 break;
-            case (Py2or3String_Type)'c':
+            case (Py_UCS4)'c':
                 if(sign) {
                     mpz_fdiv_q_2exp(upper->z, man->z, shift);
                 }
@@ -171,13 +180,13 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
                     mpz_cdiv_q_2exp(upper->z, man->z, shift);
                 }
                 break;
-            case (Py2or3String_Type)'d':
+            case (Py_UCS4)'d':
                 mpz_fdiv_q_2exp(upper->z, man->z, shift);
                 break;
-            case (Py2or3String_Type)'u':
+            case (Py_UCS4)'u':
                 mpz_cdiv_q_2exp(upper->z, man->z, shift);
                 break;
-            case (Py2or3String_Type)'n':
+            case (Py_UCS4)'n':
             default:
                 mpz_tdiv_r_2exp(lower->z, man->z, shift);
                 mpz_tdiv_q_2exp(upper->z, man->z, shift);
@@ -200,16 +209,20 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
         }
 
         if (!(tmp = PyLong_FromUnsignedLong((unsigned long)shift))) {
+            /* LCOV_EXCL_START */
             Py_DECREF((PyObject*)upper);
             Py_DECREF((PyObject*)lower);
             return NULL;
+            /* LCOV_EXCL_STOP */
         }
 
         if (!(newexp = PyNumber_Add(exp, tmp))) {
+            /* LCOV_EXCL_START */
             Py_DECREF((PyObject*)upper);
             Py_DECREF((PyObject*)lower);
             Py_DECREF(tmp);
             return NULL;
+            /* LCOV_EXCL_STOP */
         }
         Py_DECREF(tmp);
         bc = prec;
@@ -224,18 +237,22 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
     if ((zbits = mpz_scan1(upper->z, 0)))
         mpz_tdiv_q_2exp(upper->z, upper->z, zbits);
 
-    if (!(tmp = PyIntOrLong_FromLong(zbits))) {
+    if (!(tmp = GMPy_PyLong_FromMpBitCnt(zbits))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)upper);
         Py_DECREF((PyObject*)lower);
         Py_DECREF(newexp);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
     if (!(newexp2 = PyNumber_Add(newexp, tmp))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)upper);
         Py_DECREF((PyObject*)lower);
         Py_DECREF(tmp);
         Py_DECREF(newexp);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
     Py_DECREF(newexp);
     Py_DECREF(tmp);
@@ -249,37 +266,37 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
     return mpmath_build_mpf(sign, upper, newexp2, bc);
 }
 
-PyDoc_STRVAR(doc_mpmath_createg,
+PyDoc_STRVAR(doc_mpmath_create,
 "_mpmath_create(...): helper function for mpmath.");
 
 static PyObject *
-Pympz_mpmath_create(PyObject *self, PyObject *args)
+Pympz_mpmath_create_fast(PyObject *self, PyObject *const *args, Py_ssize_t nargs)
 {
-    long sign, zbits, bc = 0, prec = 0, carry = 0;
-    mp_bitcnt_t shift = 0;
+    long sign, carry = 0;
+    mp_bitcnt_t zbits, bc = 0, prec = 0, shift = 0;
     PyObject *exp = NULL, *newexp = NULL, *newexp2 = NULL, *tmp = NULL;
     MPZ_Object *man = NULL, *upper = NULL, *lower = NULL;
 
-    Py2or3String_Type rnd = (Py2or3String_Type)'f';
+    Py_UCS4 rnd = (Py_UCS4)'f';
 
-    if (PyTuple_GET_SIZE(args) < 2) {
+    if (nargs < 2) {
         TYPE_ERROR("mpmath_create() expects 'mpz','int'[,'int','str'] arguments");
         return NULL;
     }
 
-    switch (PyTuple_GET_SIZE(args)) {
+    switch (nargs) {
         case 4:
-            rnd = Py2or3String_1Char(PyTuple_GET_ITEM(args, 3));
+            rnd = PyString_1Char(args[3]);
         case 3:
-            prec = GMPy_Integer_AsLong(PyTuple_GET_ITEM(args, 2));
-            if (prec == -1) {
+            prec = GMPy_Integer_AsLong(args[2]);
+            if (prec == (mp_bitcnt_t)(-1)) {
                 VALUE_ERROR("could not convert prec to positive int");
                 return NULL;
             }
         case 2:
-            exp = PyTuple_GET_ITEM(args, 1);
+            exp = args[1];
         case 1:
-            man = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 0), NULL);
+            man = GMPy_MPZ_From_Integer(args[0], NULL);
             if (!man) {
                 TYPE_ERROR("mpmath_create() expects 'mpz','int'[,'int','str'] arguments");
                 return NULL;
@@ -294,10 +311,12 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
     upper = GMPy_MPZ_New(NULL);
     lower = GMPy_MPZ_New(NULL);
     if (!upper || !lower) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_XDECREF((PyObject*)upper);
         Py_XDECREF((PyObject*)lower);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
 
     /* Extract sign, make man positive, and set bit count */
@@ -313,7 +332,7 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
     if (bc > prec) {
         shift = bc - prec;
         switch (rnd) {
-            case (Py2or3String_Type)'f':
+            case (Py_UCS4)'f':
                 if (sign) {
                     mpz_cdiv_q_2exp(upper->z, upper->z, shift);
                 }
@@ -321,7 +340,7 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
                     mpz_fdiv_q_2exp(upper->z, upper->z, shift);
                 }
                 break;
-            case (Py2or3String_Type)'c':
+            case (Py_UCS4)'c':
                 if (sign) {
                     mpz_fdiv_q_2exp(upper->z, upper->z, shift);
                 }
@@ -329,13 +348,13 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
                     mpz_cdiv_q_2exp(upper->z, upper->z, shift);
                 }
                 break;
-            case (Py2or3String_Type)'d':
+            case (Py_UCS4)'d':
                 mpz_fdiv_q_2exp(upper->z, upper->z, shift);
                 break;
-            case (Py2or3String_Type)'u':
+            case (Py_UCS4)'u':
                 mpz_cdiv_q_2exp(upper->z, upper->z, shift);
                 break;
-            case (Py2or3String_Type)'n':
+            case (Py_UCS4)'n':
             default:
                 mpz_tdiv_r_2exp(lower->z, upper->z, shift);
                 mpz_tdiv_q_2exp(upper->z, upper->z, shift);
@@ -358,16 +377,20 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
                 }
         }
         if (!(tmp = PyLong_FromUnsignedLong((unsigned long)shift))) {
+            /* LCOV_EXCL_START */
             Py_DECREF((PyObject*)upper);
             Py_DECREF((PyObject*)lower);
             return NULL;
+            /* LCOV_EXCL_STOP */
         }
         if (!(newexp = PyNumber_Add(exp, tmp))) {
+            /* LCOV_EXCL_START */
             Py_DECREF((PyObject*)man);
             Py_DECREF((PyObject*)upper);
             Py_DECREF((PyObject*)lower);
             Py_DECREF(tmp);
             return NULL;
+            /* LCOV_EXCL_STOP */
         }
         Py_DECREF(tmp);
         bc = prec;
@@ -381,20 +404,24 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
     if ((zbits = mpz_scan1(upper->z, 0)))
         mpz_tdiv_q_2exp(upper->z, upper->z, zbits);
 
-    if (!(tmp = PyIntOrLong_FromLong(zbits))) {
+    if (!(tmp = GMPy_PyLong_FromMpBitCnt(zbits))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_DECREF((PyObject*)upper);
         Py_DECREF((PyObject*)lower);
         Py_DECREF(newexp);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
     if (!(newexp2 = PyNumber_Add(newexp, tmp))) {
+        /* LCOV_EXCL_START */
         Py_DECREF((PyObject*)man);
         Py_DECREF((PyObject*)upper);
         Py_DECREF((PyObject*)lower);
         Py_DECREF(tmp);
         Py_DECREF(newexp);
         return NULL;
+        /* LCOV_EXCL_STOP */
     }
     Py_DECREF(newexp);
     Py_DECREF(tmp);
