@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_mpz_divmod2exp.c                                                  *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -36,7 +36,7 @@
  */
 
 PyDoc_STRVAR(doc_c_divmod_2exp,
-"c_divmod_2exp(x ,n) -> (quotient, remainder)\n\n"
+"c_divmod_2exp(x, n, /) -> tuple[mpz, mpz]\n\n"
 "Return the quotient and remainder of x divided by 2**n. The quotient\n"
 "is rounded towards +Inf (ceiling rounding) and the remainder will\n"
 "be negative. x must be an integer. n must be >0.");
@@ -80,7 +80,7 @@ GMPy_MPZ_c_divmod_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_c_div_2exp,
-"c_div_2exp(x, n) -> quotient\n\n"
+"c_div_2exp(x, n, /) -> mpz\n\n"
 "Returns the quotient of x divided by 2**n. The quotient is rounded\n"
 "towards +Inf (ceiling rounding). x must be an integer. n must be >0.");
 
@@ -114,7 +114,7 @@ GMPy_MPZ_c_div_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_c_mod_2exp,
-"c_mod_2exp(x, n) -> remainder\n\n"
+"c_mod_2exp(x, n, /) -> mpz\n\n"
 "Return the remainder of x divided by 2**n. The remainder will be\n"
 "negative. x must be an integer. n must be >0.");
 
@@ -154,7 +154,7 @@ GMPy_MPZ_c_mod_2exp(PyObject *self, PyObject *args)
  */
 
 PyDoc_STRVAR(doc_f_divmod_2exp,
-"f_divmod_2exp(x, n) -> (quotient, remainder)\n\n"
+"f_divmod_2exp(x, n, /) -> tuple[mpz, mpz]\n\n"
 "Return quotient and remainder after dividing x by 2**n. The quotient\n"
 "is rounded towards -Inf (floor rounding) and the remainder will be\n"
 "positive. x must be an integer. n must be >0.");
@@ -198,7 +198,7 @@ GMPy_MPZ_f_divmod_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_f_div_2exp,
-"f_div_2exp(x, n) -? quotient\n\n"
+"f_div_2exp(x, n, /) -> mpz\n\n"
 "Return the quotient of x divided by 2**n. The quotient is rounded\n"
 "towards -Inf (floor rounding). x must be an integer. n must be >0.");
 
@@ -232,7 +232,7 @@ GMPy_MPZ_f_div_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_f_mod_2exp,
-"f_mod_2exp(x, n) -> remainder\n\n"
+"f_mod_2exp(x, n, /) -> mpz\n\n"
 "Return remainder of x divided by 2**n. The remainder will be\n"
 "positive. x must be an integer. n must be >0.");
 
@@ -272,7 +272,7 @@ GMPy_MPZ_f_mod_2exp(PyObject *self, PyObject *args)
  */
 
 PyDoc_STRVAR(doc_t_divmod_2exp,
-"t_divmod_2exp(x, n) -> (quotient, remaidner)\n\n"
+"t_divmod_2exp(x, n, /) -> tuple[mpz, mpz]\n\n"
 "Return the quotient and remainder of x divided by 2**n. The quotient\n"
 "is rounded towards zero (truncation) and the remainder will have the\n"
 "same sign as x. x must be an integer. n must be >0.");
@@ -316,7 +316,7 @@ GMPy_MPZ_t_divmod_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_t_div_2exp,
-"t_div_2exp(x, n) -> quotient\n\n"
+"t_div_2exp(x, n, /) -> mpz\n\n"
 "Return the quotient of x divided by 2**n. The quotient is rounded\n"
 "towards zero (truncation). n must be >0.");
 
@@ -350,7 +350,7 @@ GMPy_MPZ_t_div_2exp(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(doc_t_mod_2exp,
-"t_mod_2exp(x, n) -> remainder\n\n"
+"t_mod_2exp(x, n, /) -> mpz\n\n"
 "Return the remainder of x divided by 2**n. The remainder will have\n"
 "the same sign as x. x must be an integer. n must be >0.");
 
