@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_pow.c                                                             *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -24,6 +24,9 @@
  * License along with GMPY2; if not, see <http://www.gnu.org/licenses/>    *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+
+#include "pythoncapi_compat.h"
+
 /* This file implements the ** operator, Python's pow() function,
  * gmpy2.powmod(), and context.pow().
  */
@@ -50,7 +53,7 @@ GMPy_Integer_PowWithType(PyObject *b, int btype, PyObject *e, int etype,
 
     /* Try to parse the modulus value first. */
 
-    if (m == Py_None) {
+    if (Py_IsNone(m)) {
         has_mod = 0;
     }
     else {
@@ -269,7 +272,7 @@ GMPy_Integer_PowModBaseListWithType(PyObject *base_lst,
 }
 
 PyDoc_STRVAR(GMPy_doc_integer_powmod_base_list,
-"powmod_base_list(base_lst, exp, mod) -> list\n\n"
+"powmod_base_list(base_lst, exp, mod, /) -> list[mpz, ...]\n\n"
 "Returns list(powmod(i, exp, mod) for i in base_lst). Will always release\n"
 "the GIL. (Experimental in gmpy2 2.1.x).");
 
@@ -285,10 +288,10 @@ GMPy_Integer_PowMod_Base_List(PyObject *self, PyObject *args)
         TYPE_ERROR("the first argument to powmod_base_list must be a sequence");
         return NULL;
     }
-        
+
     int etype = GMPy_ObjectType(PyTuple_GET_ITEM(args, 1));
     int mtype = GMPy_ObjectType(PyTuple_GET_ITEM(args, 2));
-    
+
     if (IS_TYPE_INTEGER(etype) && IS_TYPE_INTEGER(mtype))
         return GMPy_Integer_PowModBaseListWithType(PyTuple_GET_ITEM(args, 0),
                                                    PyTuple_GET_ITEM(args, 1), etype,
@@ -372,7 +375,7 @@ GMPy_Integer_PowModExpListWithType(PyObject *b, int btype,
 }
 
 PyDoc_STRVAR(GMPy_doc_integer_powmod_exp_list,
-"powmod_exp_list(base, exp_lst, mod) -> list\n\n"
+"powmod_exp_list(base, exp_lst, mod, /) -> list[mpz, ...]\n\n"
 "Returns list(powmod(base, i, mod) for i in exp_lst). Will always release\n"
 "the GIL. (Experimental in gmpy2 2.1.x).");
 
@@ -410,7 +413,7 @@ GMPy_Rational_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
     int bsign;
     long tempexp;
 
-    if (mod != Py_None) {
+    if (!Py_IsNone(mod)) {
         TYPE_ERROR("pow() 3rd argument not allowed unless all arguments are integers");
         return NULL;
     }
@@ -486,7 +489,7 @@ GMPy_Real_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
     MPZ_Object *tempz = NULL;
     MPC_Object *mpc_result = NULL;
 
-    if (mod != Py_None) {
+    if (!Py_IsNone(mod)) {
         TYPE_ERROR("pow() 3rd argument not allowed unless all arguments are integers");
         return NULL;
     }
@@ -578,7 +581,7 @@ GMPy_Complex_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
     MPFR_Object *tempf = NULL;
     MPZ_Object *tempz = NULL;
 
-    if (mod != Py_None) {
+    if (!Py_IsNone(mod)) {
         TYPE_ERROR("pow() 3rd argument not allowed unless all arguments are integers");
         return NULL;
     }
@@ -599,7 +602,7 @@ GMPy_Complex_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
         result->rc = mpc_pow_z(result->c, tempb->c, tempz->z, GET_MPC_ROUND(context));
         goto done;
     }
-    
+
     if (IS_TYPE_REAL(etype)) {
         if (!(tempf = GMPy_MPFR_From_RealWithType(exp, etype, 1, context))) {
             goto err;
@@ -608,7 +611,7 @@ GMPy_Complex_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
         result->rc = mpc_pow_fr(result->c, tempb->c, tempf->f, GET_MPC_ROUND(context));
         goto done;
     }
-    
+
     if (IS_TYPE_COMPLEX(etype)) {
         if (!(tempe = GMPy_MPC_From_ComplexWithType(exp, etype, 1, 1, context))) {
             goto err;
@@ -639,9 +642,9 @@ GMPy_Complex_PowWithType(PyObject *base, int btype, PyObject *exp, int etype,
 }
 
 PyDoc_STRVAR(GMPy_doc_integer_powmod,
-"powmod(x, y, m) -> mpz\n\n"
+"powmod(x, y, m, /) -> mpz\n\n"
 "Return (x**y) mod m. Same as the three argument version of Python's\n"
-"built-in pow(), but converts all three arguments to mpz.");
+"built-in `pow`, but converts all three arguments to `mpz`.");
 
 static PyObject *
 GMPy_Integer_PowMod(PyObject *self, PyObject *args)
@@ -661,7 +664,7 @@ GMPy_Integer_PowMod(PyObject *self, PyObject *args)
     xtype = GMPy_ObjectType(x);
     ytype = GMPy_ObjectType(y);
     mtype = GMPy_ObjectType(m);
-    
+
     if (IS_TYPE_INTEGER(xtype) &&
         IS_TYPE_INTEGER(ytype) &&
         IS_TYPE_INTEGER(mtype)) {
@@ -674,7 +677,7 @@ GMPy_Integer_PowMod(PyObject *self, PyObject *args)
 
 
 PyDoc_STRVAR(GMPy_doc_integer_powmod_sec,
-"powmod_sec(x, y, m) -> mpz\n\n"
+"powmod_sec(x, y, m, /) -> mpz\n\n"
 "Return (x**y) mod m. Calculates x ** y (mod m) but using a constant\n"
 "time algorithm to reduce the risk of side channel attacks. y must be\n"
 "an integer >0. m must be an odd integer.");
@@ -695,7 +698,9 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     }
 
     if (!(result = GMPy_MPZ_New(NULL))) {
+        /* LCOV_EXCL_START */
         goto err;
+        /* LCOV_EXCL_STOP */
     }
 
     x = PyTuple_GET_ITEM(args, 0);
@@ -705,7 +710,7 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     xtype = GMPy_ObjectType(x);
     ytype = GMPy_ObjectType(y);
     mtype = GMPy_ObjectType(m);
-    
+
     /* Validate base. */
 
     if (!IS_TYPE_INTEGER(xtype)) {
@@ -714,7 +719,9 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     }
 
     if (!(tempx = GMPy_MPZ_From_IntegerWithType(x, xtype, NULL))) {
+        /* LCOV_EXCL_START */
         goto err;
+        /* LCOV_EXCL_STOP */
     }
 
     /* Validate exponent. It must be > 0. */
@@ -725,7 +732,9 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     }
 
     if (!(tempy = GMPy_MPZ_From_IntegerWithType(y, ytype, NULL))) {
+        /* LCOV_EXCL_START */
         goto err;
+        /* LCOV_EXCL_STOP */
     }
 
     if (!(mpz_sgn(tempy->z) == 1)) {
@@ -740,7 +749,9 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     }
 
     if (!(tempm = GMPy_MPZ_From_IntegerWithType(m, mtype, NULL))) {
+        /* LCOV_EXCL_START */
         goto err;
+        /* LCOV_EXCL_STOP */
     }
 
     if (mpz_even_p(tempm->z)) {
@@ -751,7 +762,7 @@ GMPy_Integer_PowMod_Sec(PyObject *self, PyObject *args)
     GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
     mpz_powm_sec(result->z, tempx->z, tempy->z, tempm->z);
     GMPY_MAYBE_END_ALLOW_THREADS(context);
-    
+
     Py_DECREF(tempx);
     Py_DECREF(tempy);
     Py_DECREF(tempm);
@@ -769,7 +780,7 @@ GMPy_Number_Pow(PyObject *x, PyObject *y, PyObject *z, CTXT_Object *context)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_PowWithType(x, xtype, y, ytype, z, context);
 
@@ -778,7 +789,7 @@ GMPy_Number_Pow(PyObject *x, PyObject *y, PyObject *z, CTXT_Object *context)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_PowWithType(x, xtype, y, ytype, z, context);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_PowWithType(x, xtype, y, ytype, z, context);
 
@@ -787,7 +798,7 @@ GMPy_Number_Pow(PyObject *x, PyObject *y, PyObject *z, CTXT_Object *context)
 }
 
 PyDoc_STRVAR(GMPy_doc_context_pow,
-"context.pow(x, y) -> number\n\n"
+"context.pow(x, y, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return x ** y.");
 
 static PyObject *
@@ -831,4 +842,3 @@ GMPy_Number_Pow_Slot(PyObject *base, PyObject *exp, PyObject *mod)
 
     Py_RETURN_NOTIMPLEMENTED;
 }
-
