@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy_random.c                                                           *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -39,17 +39,17 @@ static void
 GMPy_RandomState_Dealloc(RandomState_Object *self)
 {
     gmp_randclear(self->state);
-    PyObject_Del(self);
+    PyObject_Free(self);
 };
 
 static PyObject *
 GMPy_RandomState_Repr(RandomState_Object *self)
 {
-    return Py_BuildValue("s", "<gmpy2.RandomState>");
+    return PyUnicode_FromString("<gmpy2.RandomState>");
 };
 
 PyDoc_STRVAR(GMPy_doc_random_state_factory,
-"random_state([seed]) -> object\n\n"
+"random_state(seed=0, /) -> object\n\n"
 "Return new object containing state information for the random number\n"
 "generator. An optional integer can be specified as the seed value.");
 
@@ -84,7 +84,7 @@ GMPy_RandomState_Factory(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(GMPy_doc_mpz_urandomb_function,
-"mpz_urandomb(random_state, bit_count) -> mpz\n\n"
+"mpz_urandomb(random_state, bit_count, /) -> mpz\n\n"
 "Return uniformly distributed random integer between 0 and\n"
 "2**bit_count-1.");
 
@@ -122,7 +122,7 @@ GMPy_MPZ_urandomb_Function(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(GMPy_doc_mpz_rrandomb_function,
-"mpz_rrandomb(random_state, bit_count) -> mpz\n\n"
+"mpz_rrandomb(random_state, bit_count, /) -> mpz\n\n"
 "Return a random integer between 0 and 2**bit_count-1 with long\n"
 "sequences of zeros and one in its binary representation.");
 
@@ -160,7 +160,7 @@ GMPy_MPZ_rrandomb_Function(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(GMPy_doc_mpz_random_function,
-"mpz_random(random_state, int) -> mpz\n\n"
+"mpz_random(random_state, int, /) -> mpz\n\n"
 "Return uniformly distributed random integer between 0 and n-1.");
 
 static PyObject *
@@ -196,7 +196,7 @@ GMPy_MPZ_random_Function(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(GMPy_doc_mpfr_random_function,
-"mpfr_random(random_state) -> mpfr\n\n"
+"mpfr_random(random_state, /) -> mpfr\n\n"
 "Return uniformly distributed number between [0,1].");
 
 static PyObject *
@@ -227,7 +227,7 @@ GMPy_MPFR_random_Function(PyObject *self, PyObject *args)
 #if MPFR_VERSION_MAJOR > 3
 
 PyDoc_STRVAR(GMPy_doc_mpfr_nrandom_function,
-"mpfr_nrandom(random_state) -> (mpfr)\n\n"
+"mpfr_nrandom(random_state, /) -> (mpfr)\n\n"
 "Return a random number with gaussian distribution.");
 
 static PyObject *
@@ -257,7 +257,7 @@ GMPy_MPFR_nrandom_Function(PyObject *self, PyObject *args)
 }
 
 PyDoc_STRVAR(GMPy_doc_mpfr_grandom_function,
-"mpfr_grandom(random_state) -> (mpfr, mpfr)\n\n"
+"mpfr_grandom(random_state, /) -> tuple[mpfr, mpfr]\n\n"
 "Return two random numbers with gaussian distribution.");
 
 static PyObject *
@@ -304,7 +304,7 @@ GMPy_MPFR_grandom_Function(PyObject *self, PyObject *args)
 }
 #else
 PyDoc_STRVAR(GMPy_doc_mpfr_grandom_function,
-"mpfr_grandom(random_state) -> (mpfr, mpfr)\n\n"
+"mpfr_grandom(random_state, /) -> (mpfr, mpfr)\n\n"
 "Return two random numbers with gaussian distribution.");
 
 static PyObject *
@@ -349,7 +349,7 @@ GMPy_MPFR_grandom_Function(PyObject *self, PyObject *args)
 
 
 PyDoc_STRVAR(GMPy_doc_mpc_random_function,
-"mpc_random(random_state) -> mpc\n\n"
+"mpc_random(random_state, /) -> mpc\n\n"
 "Return uniformly distributed number in the unit square [0,1]x[0,1].");
 
 static PyObject *
@@ -379,39 +379,11 @@ GMPy_MPC_random_Function(PyObject *self, PyObject *args)
 
 static PyTypeObject RandomState_Type =
 {
-#ifdef PY3
     PyVarObject_HEAD_INIT(0, 0)
-#else
-    PyObject_HEAD_INIT(0)
-        0,                                  /* ob_size          */
-#endif
-    "gmpy2 random state",                   /* tp_name          */
-    sizeof(RandomState_Object),             /* tp_basicsize     */
-        0,                                  /* tp_itemsize      */
-    (destructor) GMPy_RandomState_Dealloc,  /* tp_dealloc       */
-        0,                                  /* tp_print         */
-        0,                                  /* tp_getattr       */
-        0,                                  /* tp_setattr       */
-        0,                                  /* tp_reserved      */
-    (reprfunc) GMPy_RandomState_Repr,       /* tp_repr          */
-        0,                                  /* tp_as_number     */
-        0,                                  /* tp_as_sequence   */
-        0,                                  /* tp_as_mapping    */
-        0,                                  /* tp_hash          */
-        0,                                  /* tp_call          */
-        0,                                  /* tp_str           */
-        0,                                  /* tp_getattro      */
-        0,                                  /* tp_setattro      */
-        0,                                  /* tp_as_buffer     */
-    Py_TPFLAGS_DEFAULT,                     /* tp_flags         */
-    "GMPY2 Random number generator state",  /* tp_doc           */
-        0,                                  /* tp_traverse      */
-        0,                                  /* tp_clear         */
-        0,                                  /* tp_richcompare   */
-        0,                                  /* tp_weaklistoffset*/
-        0,                                  /* tp_iter          */
-        0,                                  /* tp_iternext      */
-        0,                                  /* tp_methods       */
-        0,                                  /* tp_members       */
-        0,                                  /* tp_getset        */
+    .tp_name = "gmpy2.random_state",       
+    .tp_basicsize = sizeof(RandomState_Object),     
+    .tp_dealloc = (destructor) GMPy_RandomState_Dealloc, 
+    .tp_repr = (reprfunc) GMPy_RandomState_Repr,
+    .tp_flags = Py_TPFLAGS_DEFAULT, 
+    .tp_doc = "GMPY2 Random number generator state", 
 };
