@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_sub.c                                                             *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -32,7 +32,7 @@
  * converted into an mpz, Py_NotImplemented is returned. */
 
 static PyObject *
-GMPy_Integer_SubWithType(PyObject *x, int xtype, PyObject *y, int ytype, 
+GMPy_Integer_SubWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                          CTXT_Object *context)
 {
     MPZ_Object *result = NULL;
@@ -63,7 +63,7 @@ GMPy_Integer_SubWithType(PyObject *x, int xtype, PyObject *y, int ytype,
                 }
             }
             else {
-                mpz_set_PyIntOrLong(result->z, y);
+                mpz_set_PyLong(result->z, y);
                 GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
                 mpz_sub(result->z, MPZ(x), result->z);
                 GMPY_MAYBE_END_ALLOW_THREADS(context);
@@ -88,7 +88,7 @@ GMPy_Integer_SubWithType(PyObject *x, int xtype, PyObject *y, int ytype,
             }
             else {
                 GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-                mpz_set_PyIntOrLong(result->z, x);
+                mpz_set_PyLong(result->z, x);
                 mpz_sub(result->z, result->z, MPZ(y));
                 GMPY_MAYBE_END_ALLOW_THREADS(context);
             }
@@ -117,9 +117,11 @@ GMPy_Integer_SubWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("sub() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 /* Subtract two Rational objects (see gmpy2_convert.h). Returns None and
@@ -288,7 +290,7 @@ GMPy_Number_Sub(PyObject *x, PyObject *y, CTXT_Object *context)
 
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_SubWithType(x, xtype, y, ytype, context);
 
@@ -297,7 +299,7 @@ GMPy_Number_Sub(PyObject *x, PyObject *y, CTXT_Object *context)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_SubWithType(x, xtype, y, ytype, context);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_SubWithType(x, xtype, y, ytype, context);
 
@@ -315,7 +317,7 @@ GMPy_Number_Sub_Slot(PyObject *x, PyObject *y)
 
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_SubWithType(x, xtype, y, ytype, context);
 
@@ -324,7 +326,7 @@ GMPy_Number_Sub_Slot(PyObject *x, PyObject *y)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_SubWithType(x, xtype, y, ytype, context);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_SubWithType(x, xtype, y, ytype, context);
 
@@ -334,11 +336,11 @@ GMPy_Number_Sub_Slot(PyObject *x, PyObject *y)
 /* Implement context.sub() and gmpy2.sub(). */
 
 PyDoc_STRVAR(GMPy_doc_sub,
-"sub(x, y) -> number\n\n"
+"sub(x, y, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return x - y.");
 
 PyDoc_STRVAR(GMPy_doc_context_sub,
-"context.sub(x, y) -> number\n\n"
+"context.sub(x, y, /) -> mpz | mpq | mpfr | mpc\n\n"
 "Return x - y.");
 
 static PyObject *
@@ -362,4 +364,3 @@ GMPy_Context_Sub(PyObject *self, PyObject *args)
                            PyTuple_GET_ITEM(args, 1),
                            context);
 }
-
