@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * ** * * * * * * * * * * * * * * * *
  * gmpy2_xmpz_inplace.c                                                     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -54,10 +54,13 @@ GMPy_XMPZ_IAdd_Slot(PyObject *self, PyObject *other)
             }
         }
         else {
-            mpz_set_PyIntOrLong(global.tempz, other);
+            mpz_t tempz;
+            mpz_init(tempz);
+            mpz_set_PyLong(tempz, other);
             GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-            mpz_add(MPZ(self), MPZ(self), global.tempz);
+            mpz_add(MPZ(self), MPZ(self), tempz);
             GMPY_MAYBE_END_ALLOW_THREADS(context);
+            mpz_clear(tempz);
         }
         Py_INCREF(self);
         return self;
@@ -98,10 +101,13 @@ GMPy_XMPZ_ISub_Slot(PyObject *self, PyObject *other)
             }
         }
         else {
-            mpz_set_PyIntOrLong(global.tempz, other);
+            mpz_t tempz;
+            mpz_init(tempz);
+            mpz_set_PyLong(tempz, other);
             GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-            mpz_sub(MPZ(self), MPZ(self), global.tempz);
+            mpz_sub(MPZ(self), MPZ(self), tempz);
             GMPY_MAYBE_END_ALLOW_THREADS(context);
+            mpz_clear(tempz);
         }
         Py_INCREF(self);
         return self;
@@ -137,10 +143,13 @@ GMPy_XMPZ_IMul_Slot(PyObject *self, PyObject *other)
             mpz_mul_si(MPZ(self), MPZ(self), temp);
         }
         else {
-            mpz_set_PyIntOrLong(global.tempz, other);
+            mpz_t tempz;
+            mpz_init(tempz);
+            mpz_set_PyLong(tempz, other);
             GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-            mpz_mul(MPZ(self), MPZ(self), global.tempz);
+            mpz_mul(MPZ(self), MPZ(self), tempz);
             GMPY_MAYBE_END_ALLOW_THREADS(context);
+            mpz_clear(tempz);
         }
         Py_INCREF(self);
         return self;
@@ -188,10 +197,13 @@ GMPy_XMPZ_IFloorDiv_Slot(PyObject *self, PyObject *other)
             }
         }
         else {
-            mpz_set_PyIntOrLong(global.tempz, other);
+            mpz_t tempz;
+            mpz_init(tempz);
+            mpz_set_PyLong(tempz, other);
             GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-            mpz_fdiv_q(MPZ(self), MPZ(self), global.tempz);
+            mpz_fdiv_q(MPZ(self), MPZ(self), tempz);
             GMPY_MAYBE_END_ALLOW_THREADS(context);
+            mpz_clear(tempz);
         }
         Py_INCREF(self);
         return self;
@@ -240,10 +252,13 @@ GMPy_XMPZ_IRem_Slot(PyObject *self, PyObject *other)
             }
         }
         else {
-            mpz_set_PyIntOrLong(global.tempz, other);
+            mpz_t tempz;
+            mpz_init(tempz);
+            mpz_set_PyLong(tempz, other);
             GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-            mpz_fdiv_r(MPZ(self), MPZ(self), global.tempz);
+            mpz_fdiv_r(MPZ(self), MPZ(self), tempz);
             GMPY_MAYBE_END_ALLOW_THREADS(context);
+            mpz_clear(tempz);
         }
         Py_INCREF(self);
         return self;
@@ -304,8 +319,8 @@ GMPy_XMPZ_ILshift_Slot(PyObject *self, PyObject *other)
 static PyObject *
 GMPy_XMPZ_IPow_Slot(PyObject *self, PyObject *other, PyObject *mod)
 {
-    mp_bitcnt_t exp = GMPy_Integer_AsMpBitCnt(other);
-    if (exp == (mp_bitcnt_t)(-1) && PyErr_Occurred())
+    unsigned long exp = GMPy_Integer_AsUnsignedLong(other);
+    if (exp == (unsigned long)(-1) && PyErr_Occurred())
         return NULL;
 
     mpz_pow_ui(MPZ(self), MPZ(self), exp);
@@ -332,11 +347,14 @@ GMPy_XMPZ_IAnd_Slot(PyObject *self, PyObject *other)
         return self;
     }
 
-    if (PyIntOrLong_Check(other)) {
-        mpz_set_PyIntOrLong(global.tempz, other);
+    if (PyLong_Check(other)) {
+        mpz_t tempz;
+        mpz_init(tempz);
+        mpz_set_PyLong(tempz, other);
         GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-        mpz_and(MPZ(self), MPZ(self), global.tempz);
+        mpz_and(MPZ(self), MPZ(self), tempz);
         GMPY_MAYBE_END_ALLOW_THREADS(context);
+        mpz_clear(tempz);
         Py_INCREF(self);
         return self;
     }
@@ -361,11 +379,14 @@ GMPy_XMPZ_IXor_Slot(PyObject *self, PyObject *other)
         return self;
     }
 
-    if(PyIntOrLong_Check(other)) {
-        mpz_set_PyIntOrLong(global.tempz, other);
+    if(PyLong_Check(other)) {
+        mpz_t tempz;
+        mpz_init(tempz);
+        mpz_set_PyLong(tempz, other);
         GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-        mpz_xor(MPZ(self), MPZ(self), global.tempz);
+        mpz_xor(MPZ(self), MPZ(self), tempz);
         GMPY_MAYBE_END_ALLOW_THREADS(context);
+        mpz_clear(tempz);
         Py_INCREF(self);
         return self;
     }
@@ -390,11 +411,14 @@ GMPy_XMPZ_IIor_Slot(PyObject *self, PyObject *other)
         return self;
     }
 
-    if(PyIntOrLong_Check(other)) {
-        mpz_set_PyIntOrLong(global.tempz, other);
+    if(PyLong_Check(other)) {
+        mpz_t tempz;
+        mpz_init(tempz);
+        mpz_set_PyLong(tempz, other);
         GMPY_MAYBE_BEGIN_ALLOW_THREADS(context);
-        mpz_ior(MPZ(self), MPZ(self), global.tempz);
+        mpz_ior(MPZ(self), MPZ(self), tempz);
         GMPY_MAYBE_END_ALLOW_THREADS(context);
+        mpz_clear(tempz);
         Py_INCREF(self);
         return self;
     }
