@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_xmpz_misc.h                                                       *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2022 Case Van Horsen                                   *
+ * Copyright 2008 - 2024 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -58,12 +58,6 @@ static PyObject *         GMPy_XMPZ_Method_IterClear(PyObject *self, PyObject *a
 static PyObject *         GMPy_XMPZ_Method_SizeOf(PyObject *self, PyObject *other);
 
 
-#if PY_MAJOR_VERSION < 3
-/* hex/oct formatting (mpz-only) */
-static PyObject * GMPy_XMPZ_Oct_Slot(XMPZ_Object *self);
-static PyObject * GMPy_XMPZ_Hex_Slot(XMPZ_Object *self);
-#endif
-
 #ifdef __cplusplus
 }
 #endif
